=======
Credits
=======

Development Lead
----------------

* `Henrik Blidh <henrik.blidh@nedomkull.com>`_

Contributors (sorted alphabetically)
------------------------------------

* `Jonas Böer <https://github.com/morgil>`_ (Kinemic GmbH)
    - Magnetometer module

* `Thibaud Mathieu <https://github.com/enlight3d>`_
    - Raw example for temperature module

* `MBIENTLAB INC <hello@mbientlab.com>`_
    - Some refactoring and corrections

* `m-georgi <https://github.com/m-georgi>`_
    - Sensor fusion module

* `Eric Tsai <https://github.com/scaryghost>`_ (MBIENTLAB INC)
    - 64-bit datasignal address handling and typecasting

* `Daniel Matthes <https://github.com/dmatthes1982>`_ (MPI-CBS)
    - Accelerometer data logging feature
